<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU" sourcelanguage="en">
<context>
    <name>APTSourceEdit</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="14"/>
        <source>APT Repository Edit</source>
        <translation>Правка репозитория APT</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="38"/>
        <source>APT Repository</source>
        <translation>Репозиторий APT</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="48"/>
        <source>Components</source>
        <translation>Компоненты</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="55"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="71"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="87"/>
        <source>Fields cannot be left blank.</source>
        <translation>Необходимо заполнить поля.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="94"/>
        <source>URI</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="110"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="133"/>
        <source>Suites</source>
        <translation>Сьюты</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="152"/>
        <source>Source</source>
        <translation>Исходный код</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_edit.ui" line="177"/>
        <source>Binary</source>
        <translation>Готовые пакеты</translation>
    </message>
</context>
<context>
    <name>APTSourceManagerPage</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="188"/>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="226"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="14"/>
        <source>APT Repository Manager</source>
        <translation>Менеджер репозиториев APT</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="125"/>
        <source>Not Found APT Repositories</source>
        <translation>Репозитории APT не найдены</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="269"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="308"/>
        <source>Enable Source</source>
        <translation>Включить источник</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="338"/>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="95"/>
        <source>Add Repository</source>
        <translation>Добавить репозиторий</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="371"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.ui" line="419"/>
        <source>Select to delete or edit.</source>
        <translation>Выберите для удаления или правки.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="24"/>
        <source>example %1</source>
        <translation>пример %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="63"/>
        <source>APT Repositories (%1)</source>
        <translation>Репозиториев APT (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="69"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_manager_page.cpp" line="75"/>
        <source>Adding...</source>
        <translation>Добавление...</translation>
    </message>
</context>
<context>
    <name>APTSourceRepositoryItem</name>
    <message>
        <location filename="../stacer/Pages/AptSourceManager/apt_source_repository_item.cpp" line="35"/>
        <source>%1 (Source Code)</source>
        <translation>%1 (Исходный код)</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="../stacer/app.ui" line="101"/>
        <source>Dashboard</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="135"/>
        <source>Startup Apps</source>
        <translation>Автозапуск приложений</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="163"/>
        <source>System Cleaner</source>
        <translation>Очистка системы</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="194"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="278"/>
        <source>Uninstaller</source>
        <translation>Удаление пакетов</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="306"/>
        <source>Resources</source>
        <translation>Ресурсы</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="334"/>
        <source>Helpers</source>
        <translation>Помощники</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="362"/>
        <source>APT Repository Manager</source>
        <translation>Менеджер репозиториев APT</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="250"/>
        <source>Processes</source>
        <translation>Процессы</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="222"/>
        <source>Services</source>
        <translation>Службы</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="390"/>
        <source>Gnome Settings</source>
        <translation>Настройки Gnome</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="418"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../stacer/app.ui" line="459"/>
        <source>Feedback</source>
        <translation>Обратная связь</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="108"/>
        <location filename="../stacer/app.cpp" line="115"/>
        <location filename="../stacer/app.cpp" line="173"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="110"/>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="113"/>
        <source>Don&apos;t ask again.</source>
        <translation>Более не спрашивать.</translation>
    </message>
    <message>
        <location filename="../stacer/app.cpp" line="116"/>
        <source>Will the program continue to work in the system tray?</source>
        <translation>Продолжить работу программы в системном трее?</translation>
    </message>
</context>
<context>
    <name>AppearanceSettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="44"/>
        <source>Screen Applications</source>
        <translation>Экранные приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="74"/>
        <source>Screen Reader</source>
        <translation>Чтение с экрана</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="100"/>
        <source>Screen Keyboard</source>
        <translation>Экранная клавиатура</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="136"/>
        <source>Background Image Mode</source>
        <translation>Режим фонового изображения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="166"/>
        <source>Desktop Mode</source>
        <translation>Режим рабочего стола</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="204"/>
        <source>Login Mode</source>
        <translation>Режим экрана блокировки</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="252"/>
        <source>Icons</source>
        <translation>Значки</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="282"/>
        <source>Home Icon</source>
        <translation>Значок домашнего каталога</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="308"/>
        <source>Trash Icon</source>
        <translation>Значок корзины</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="321"/>
        <source>Mounted Volumes Icon</source>
        <translation>Значок примонтированных томов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="347"/>
        <source>Show Desktop Icons</source>
        <translation>Показывать значки на рабочем столе</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.ui" line="373"/>
        <source>Network Icon</source>
        <translation>Значок сети</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>None</source>
        <translation>Не выбрано</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Wallpaper</source>
        <translation>Обои</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Centered</source>
        <translation>По центру</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Scaled</source>
        <translation>Масштабирование</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Stretched</source>
        <translation>Растягивание</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Zoom</source>
        <translation>Увеличение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/appearance_settings.cpp" line="71"/>
        <source>Spanned</source>
        <translation>Заполнение</translation>
    </message>
</context>
<context>
    <name>DashboardPage</name>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="20"/>
        <source>Dashboard</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="156"/>
        <source>SYSTEM INFO</source>
        <translation>СВЕДЕНИЯ О СИСТЕМЕ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="230"/>
        <source>A new update is now available.</source>
        <translation>Доступно обновление.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.ui" line="246"/>
        <source>Download</source>
        <translation>Скачать</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="18"/>
        <source>CPU</source>
        <translation>ЦП</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="19"/>
        <source>MEMORY</source>
        <translation>ПАМЯТЬ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="20"/>
        <source>DISK</source>
        <translation>ДИСК</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="21"/>
        <source>DOWNLOAD</source>
        <translation>ПОЛУЧЕНИЕ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="22"/>
        <source>UPLOAD</source>
        <translation>ОТПРАВКА</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="111"/>
        <source>Hostname: %1</source>
        <translation>Имя компьютера: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="112"/>
        <source>Platform: %1</source>
        <translation>Платформа: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="113"/>
        <source>Distribution: %1</source>
        <translation>Дистрибутив: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="114"/>
        <source>Kernel Release: %1</source>
        <translation>Версия ядра: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="115"/>
        <source>CPU Model: %1</source>
        <translation>Модель ЦП: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="116"/>
        <source>CPU Core: %1</source>
        <translation>Ядра ЦП: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="117"/>
        <source>CPU Speed: %1</source>
        <translation>Частота ЦП: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="135"/>
        <source>High CPU Usage</source>
        <translation>Высокая загрузка процессора</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="136"/>
        <source>The amount of CPU used is over %1%.</source>
        <translation>Использование процессора превышает %1%.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="164"/>
        <source>High Memory Usage</source>
        <translation>Высокое потребление памяти</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="165"/>
        <source>The amount of memory used is over %1%.</source>
        <translation>Использование памяти превышает %1%.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="208"/>
        <source>High Disk Usage</source>
        <translation>Высокая загрузка диска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="209"/>
        <source>The amount of disk used is over %1%.</source>
        <translation>Использование диска превышает %1%.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="247"/>
        <location filename="../stacer/Pages/Dashboard/dashboard_page.cpp" line="251"/>
        <source>Total: %1</source>
        <translation>Всего: %1</translation>
    </message>
</context>
<context>
    <name>Feedback</name>
    <message>
        <location filename="../stacer/feedback.ui" line="14"/>
        <source>Feedback</source>
        <translation>Отправить отзыв</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="61"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="68"/>
        <source>Email Address</source>
        <translation>Электронная почта</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="97"/>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="120"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="54"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.ui" line="78"/>
        <source>Send feedback</source>
        <translation>Отправить отзыв</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="46"/>
        <source>Email address is not valid !</source>
        <translation>Недопустимый адрес электронной почты!</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="51"/>
        <source>Your message must be at least 5 characters !</source>
        <translation>Ваше сообщение должно быть не менее 5 символов!</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="59"/>
        <source>Sending...</source>
        <translation>Отправка...</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="78"/>
        <source>&lt;font color=&apos;#2ecc71&apos;&gt;Your feedback has been successfully sent. Thanks!&lt;/font&gt;</source>
        <translation>&lt;font color=&apos;#2ecc71&apos;&gt;Ваш отзыв успешно отправлен. Спасибо!&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="80"/>
        <location filename="../stacer/feedback.cpp" line="85"/>
        <source>Something went wrong, try again !</source>
        <translation>Что-то пошло не так, повторите попытку!</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="88"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../stacer/feedback.cpp" line="93"/>
        <source>Fields cannot be left blank !</source>
        <translation>Поля нельзя оставлять пустыми!</translation>
    </message>
</context>
<context>
    <name>GnomeSettingsPage</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="14"/>
        <source>Gnome Settings</source>
        <translation>Настройки Gnome</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="49"/>
        <source>Unity Settings</source>
        <translation>Настройки Unity</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="81"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/gnome_settings_page.ui" line="110"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
</context>
<context>
    <name>HelpersPage</name>
    <message>
        <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="14"/>
        <source>Helpers</source>
        <translation>Помощники</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/helpers_page.ui" line="62"/>
        <source>Host Manage</source>
        <translation>Управление хостами</translation>
    </message>
</context>
<context>
    <name>HostManage</name>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="63"/>
        <source>Save Changes</source>
        <translation>Сохранить изменения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="110"/>
        <source>New Host</source>
        <translation>Новый хост</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="146"/>
        <source>IP Address *</source>
        <translation>Адрес IP *</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="153"/>
        <source>Fully Qualified Name *</source>
        <translation>Полное имя *</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="160"/>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>Aliases</source>
        <translation>Псевдонимы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="176"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.ui" line="192"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="26"/>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="100"/>
        <source>Hosts (%1)</source>
        <translation>Хост (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>IP Address</source>
        <translation>Адрес IP</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="39"/>
        <source>Full Qualified</source>
        <translation>Полное</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="137"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="141"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Helpers/host_manage.cpp" line="149"/>
        <source>The IP and Fully Qualified fields are required.</source>
        <translation>Поля Адреса IP и Полного имени являются обязательными.</translation>
    </message>
</context>
<context>
    <name>ProcessesPage</name>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="14"/>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="55"/>
        <source>Processes</source>
        <translation>Процессы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="71"/>
        <source>All Processes</source>
        <translation>Все процессы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="96"/>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.ui" line="217"/>
        <source>End Process</source>
        <translation>Завершить процесс</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>User</source>
        <translation>Пользователь</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>Resident Memory</source>
        <translation>Резидентная память</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>%Memory</source>
        <translation>%Память</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="29"/>
        <source>Virtual Memory</source>
        <translation>Виртуальная память</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>Start Time</source>
        <translation>Запущен</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>State</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="30"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Nice</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>CPU Time</source>
        <translation>Время ЦП</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Session</source>
        <translation>Сеанс</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="31"/>
        <source>Process</source>
        <translation>Процесс</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="120"/>
        <source>Processes (%1)</source>
        <translation>Процессы (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Processes/processes_page.cpp" line="215"/>
        <source>Refresh (%1)</source>
        <translation>Обновление (%1)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../stacer/Managers/setting_manager.cpp" line="61"/>
        <source>Dashboard</source>
        <translation>Обзор</translation>
    </message>
</context>
<context>
    <name>ResourcesPage</name>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="14"/>
        <source>History of CPU</source>
        <translation>История процессора</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="15"/>
        <source>History of CPU Load Averages</source>
        <translation>История средней загрузки процессора</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="16"/>
        <source>History of Disk Read Write</source>
        <translation>История чтения и записи диска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="17"/>
        <source>History of Memory</source>
        <translation>История памяти</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="18"/>
        <source>History of Network</source>
        <translation>История сети</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="106"/>
        <source>File System</source>
        <translation>Файловая система</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="122"/>
        <source>File System Type</source>
        <translation>Тип файловой системы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="142"/>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="217"/>
        <source>Read: %1/s Total: %2</source>
        <translation>Чтение: %1/c Всего: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="222"/>
        <source>Write: %1/s Total: %2</source>
        <translation>Запись: %1/c Всего: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="259"/>
        <source>%1 Minute Average: %2</source>
        <translation>Среднее за %1 минут: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="307"/>
        <source>Download: %1/s Total: %2</source>
        <translation>Получение: %1/c Всего: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="312"/>
        <source>Upload: %1/s  Total: %2</source>
        <translation>Отправка: %1/c Всего: %2</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="356"/>
        <source>Swap: %1 (%2%) %3</source>
        <translation>Файл подкачки: %1 (%2%) %3</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.cpp" line="365"/>
        <source>Memory: %1 (%2%) %3</source>
        <translation>Память: %1 (%2%) %3</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Resources/resources_page.ui" line="14"/>
        <source>Resources</source>
        <translation>Ресурсы</translation>
    </message>
</context>
<context>
    <name>SearchPage</name>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="14"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="101"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="113"/>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="211"/>
        <source>Case Insensitive</source>
        <translation>Без учёта регистра</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="298"/>
        <source> minute</source>
        <translation> минута</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="370"/>
        <source>Search as Root</source>
        <translation>Искать с правами Root</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="377"/>
        <source>Owner</source>
        <translation>Владелец</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="406"/>
        <source>RegEx</source>
        <translation>Регулярное выражение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="483"/>
        <source>Permissions</source>
        <translation>Права</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="490"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="27"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="514"/>
        <source>Readable</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="530"/>
        <source>Writable</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="546"/>
        <source>Executable</source>
        <translation>Исполняемый</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="555"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="584"/>
        <source>Empty</source>
        <translation>Пустой</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="591"/>
        <source>File or Folder:</source>
        <translation>Файл или папка:</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="607"/>
        <source>Invert</source>
        <translation>Обратить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="650"/>
        <source>Advanced Search</source>
        <translation>Расширенный поиск</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.ui" line="690"/>
        <source>BETA version</source>
        <translation>БЕТА-версия</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="25"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="26"/>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="28"/>
        <source>User</source>
        <translation>Пользователь</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="29"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="30"/>
        <source>Creation Time</source>
        <translation>Дата создания</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="31"/>
        <source>Last Access</source>
        <translation>Последний доступ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="32"/>
        <source>Last Modification</source>
        <translation>Последняя правка</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="33"/>
        <source>Last Change</source>
        <translation>Последнее изменение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="88"/>
        <source>Open Folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="92"/>
        <source>Move Trash</source>
        <translation>Убрать в корзину</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="96"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="129"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="132"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="140"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="149"/>
        <source>Choose</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="135"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="136"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="137"/>
        <source>Directory</source>
        <translation>Каталог</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="138"/>
        <source>Symbolic Link</source>
        <translation>Символическая ссылка</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="141"/>
        <source>Access</source>
        <translation>Доступ</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="142"/>
        <source>Modify</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="143"/>
        <source>Change</source>
        <translation>Изменение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="145"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="150"/>
        <source>Smaller (&lt;)</source>
        <translation>Меньше (&lt;)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="146"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="151"/>
        <source>Equal (=)</source>
        <translation>Равно (=)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="147"/>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="152"/>
        <source>Greater (&gt;)</source>
        <translation>Больше (&gt;)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="162"/>
        <source>Select Directory</source>
        <translation>Выбрать каталог</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="168"/>
        <source>Directory: %1</source>
        <translation>Каталог: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="177"/>
        <source>Advanced Search %1</source>
        <translation>Расширенный поиск %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="195"/>
        <source>Select the search directory.</source>
        <translation>Выбрать каталог поиска.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="293"/>
        <source>Somethings went wrong, try again.</source>
        <translation>Что-то пошло не так, повторите попытку.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Search/search_page.cpp" line="309"/>
        <source>%1 files found. Showing %2 of them.</source>
        <translation>Найдено файлов: %1. Из них показано: %2.</translation>
    </message>
</context>
<context>
    <name>ServicesPage</name>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="14"/>
        <source>Services</source>
        <translation>Службы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="137"/>
        <source>Startup at boot ?</source>
        <translation>Запускать при загрузке?</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="190"/>
        <source>Running Now ?</source>
        <translation>Запущена сейчас?</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.ui" line="244"/>
        <source>Not Found System Service</source>
        <translation>Системные службы не найдены</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Running Status</source>
        <translation>Состояние запуска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Running</source>
        <translation>Запущена</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="32"/>
        <source>Not Running</source>
        <translation>Не запущена</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Startup Status</source>
        <translation>Состояние автозапуска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="33"/>
        <source>Disabled</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Services/services_page.cpp" line="80"/>
        <source>System Services (%1)</source>
        <translation>Системные службы (%1)</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="97"/>
        <source>Memory Percent</source>
        <translation>Процент памяти</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="129"/>
        <source>Disk Percent</source>
        <translation>Процент диска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="329"/>
        <source>App Quit Don&apos;t Ask</source>
        <translation>Не спрашивать при выходе</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="389"/>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="158"/>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="171"/>
        <source>Autostart Stacer</source>
        <translation>Автозапускать Stacer</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="229"/>
        <source>Alert messages (Show a warning after the specified percentage)</source>
        <translation>Показывать предупреждение после указанного процента</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="402"/>
        <source>Start Page</source>
        <translation>Стартовая страница</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="213"/>
        <source>CPU Percent</source>
        <translation>Загрузка ЦП</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.ui" line="267"/>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Dashboard</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Startup Apps</source>
        <translation>Запускаемые приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>System Cleaner</source>
        <translation>Очистка системы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="83"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Services</source>
        <translation>Службы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Processes</source>
        <translation>Процессы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Uninstaller</source>
        <translation>Удаление пакетов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Resources</source>
        <translation>Ресурсы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Settings/settings_page.cpp" line="84"/>
        <source>Helpers</source>
        <translation>Помощники</translation>
    </message>
</context>
<context>
    <name>StartupApp</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app.ui" line="128"/>
        <source>Edit App</source>
        <translation>Править приложение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app.ui" line="150"/>
        <source>Delete App</source>
        <translation>Удалить приложение</translation>
    </message>
</context>
<context>
    <name>StartupAppEdit</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="20"/>
        <source>Startup App</source>
        <translation>Автозапуск приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="95"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="44"/>
        <source>Fields cannot be left blank.</source>
        <translation>Необходимо заполнить поля.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="65"/>
        <source>App Comment</source>
        <translation>Описание приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="51"/>
        <source>App Name</source>
        <translation>Имя приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="58"/>
        <source>Generic Name</source>
        <translation>Общее название</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="72"/>
        <source>App Icon</source>
        <translation>Значок приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="79"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_app_edit.ui" line="108"/>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
</context>
<context>
    <name>StartupAppsPage</name>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="201"/>
        <source>Not Found Startup Apps</source>
        <translation>Автоматически запускаемые приложения не найдены</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="14"/>
        <source>Startup Apps</source>
        <translation>Автозапуск приложений</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.ui" line="101"/>
        <source>Add Startup App</source>
        <translation>Добавить приложение в автозапуск</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="67"/>
        <source>Startup Apps are disabled.</source>
        <translation>Автоматически запускаемые приложения отключены.</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/StartupApps/startup_apps_page.cpp" line="127"/>
        <source>Startup Applications (%1)</source>
        <translation>Автоматически запускаемые приложения (%1)</translation>
    </message>
</context>
<context>
    <name>SystemCleanerPage</name>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="14"/>
        <source>System Cleaner</source>
        <translation>Очистка системы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="66"/>
        <source>Crash Reports</source>
        <translation>Отчёты об ошибках</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="180"/>
        <source>Application Logs</source>
        <translation>Журналы приложений</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="218"/>
        <source>Application Caches</source>
        <translation>Кэш приложений</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="366"/>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="404"/>
        <source>Package Caches</source>
        <translation>Загруженные пакеты</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="493"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="638"/>
        <source>Select all</source>
        <translation>Выбрать все</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="651"/>
        <source> Back</source>
        <translation> Назад</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="759"/>
        <source>Sort by: </source>
        <translation>Сортировка: </translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="773"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="782"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="33"/>
        <source>File Name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="180"/>
        <source>Total size: %1</source>
        <translation>Общий размер: %1</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="791"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.ui" line="800"/>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="33"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/SystemCleaner/system_cleaner_page.cpp" line="293"/>
        <source>%1 size files cleaned.</source>
        <translation>Освобождено %1.</translation>
    </message>
</context>
<context>
    <name>UninstallerPage</name>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="14"/>
        <source>Uninstaller</source>
        <translation>Удаление пакетов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="371"/>
        <source>System Packages</source>
        <translation>Пакеты системы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="393"/>
        <source>Snap Packages</source>
        <translation>Пакеты Snap</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="442"/>
        <source>Search...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="108"/>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="231"/>
        <source>Not Found Installed Packages</source>
        <translation>Установленные пакеты не найдены</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstallerpage.ui" line="340"/>
        <source>Uninstall Selected</source>
        <translation>Удалить выбранные</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="102"/>
        <source>Packages (%1)</source>
        <translation>Пакеты (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="107"/>
        <source>Snap Packages (%1)</source>
        <translation>Пакеты Snap (%1)</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="208"/>
        <location filename="../stacer/Pages/Uninstaller/uninstaller_page.cpp" line="215"/>
        <source>Uninstall Selected (%1)</source>
        <translation>Удалить выбранные (%1)</translation>
    </message>
</context>
<context>
    <name>UnitySettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="65"/>
        <source>Applications</source>
        <translation>Приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="108"/>
        <source>Show &quot;Recently Used&quot; applications</source>
        <translation>Показывать недавние приложения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="134"/>
        <source>Enable search of your files</source>
        <translation>Включить поиск ваших файлов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="160"/>
        <source>Show &quot;More Suggestions&quot;</source>
        <translation>Показывать &quot;Другие рекомендации&quot;</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="186"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="196"/>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="683"/>
        <source>General</source>
        <translation>Основное</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="229"/>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="660"/>
        <source>Transparency Level</source>
        <translation>Прозрачность</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="280"/>
        <source>Behaviour</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="323"/>
        <source>Auto Hide</source>
        <translation>Скрывать автоматически</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="339"/>
        <source>Left Side</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="380"/>
        <source>Minimize applications with clicking</source>
        <translation>Минимизация приложений по щелчку</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="396"/>
        <source>Top-Left Corner</source>
        <translation>Верхний левый угол</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="412"/>
        <source>Reveal Sensitivity</source>
        <translation>Скорость открытия</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="438"/>
        <source>Reveal Location</source>
        <translation>Место открытия</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="464"/>
        <source>Launcher</source>
        <translation>Панель запуска</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="474"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="507"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="526"/>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="542"/>
        <source>Visibility</source>
        <translation>Видимость</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="558"/>
        <source>Primary Desktop</source>
        <translation>Основной рабочий стол</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="612"/>
        <source>Icon size</source>
        <translation>Размер значков</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="628"/>
        <source>All Desktops</source>
        <translation>Все рабочие столы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="644"/>
        <source>Position</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="726"/>
        <source>Search online sources</source>
        <translation>Поиск результатов в сети</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="752"/>
        <source>Background Blur</source>
        <translation>Фоновое размытие</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="778"/>
        <source>Panel</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="801"/>
        <source>Indicators</source>
        <translation>Индикаторы</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="840"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="862"/>
        <source>Calendar</source>
        <translation>Календарь</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="875"/>
        <source>Date &amp; Time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="888"/>
        <source>24-Hour Time</source>
        <translation>24-часовой формат</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="910"/>
        <source>Weekday</source>
        <translation>День недели</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="923"/>
        <source>Include</source>
        <translation>Добавлять</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="945"/>
        <source>Seconds</source>
        <translation>Секунды</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="958"/>
        <source>Volume</source>
        <translation>Громкость</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/unity_settings.ui" line="971"/>
        <source>Show my name</source>
        <translation>Показывать моё имя</translation>
    </message>
</context>
<context>
    <name>WindowManagerSettings</name>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="90"/>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="100"/>
        <source>Titlebar Actions</source>
        <translation>Действия заголовка</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="155"/>
        <source>Right click</source>
        <translation>Правый щелчок</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="168"/>
        <source>Double click</source>
        <translation>Двойной щелчок</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="181"/>
        <source>Middle click</source>
        <translation>Щелчок средней кнопкой</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="257"/>
        <source>Additional</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="267"/>
        <source>Workspace Settings</source>
        <translation>Настройка рабочего окружения</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="310"/>
        <source>Vertical workspaces</source>
        <translation>Вертикальных рабочих столов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="333"/>
        <source>Workspace switcher</source>
        <translation>Переключение рабочих столов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="356"/>
        <source>Horizontal workspaces</source>
        <translation>Горизонтальных рабочих столов</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="379"/>
        <source>Focus Behaviour</source>
        <translation>Поведение фокуса</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="409"/>
        <source>Focus mode</source>
        <translation>Режим фокусировки</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="460"/>
        <source>Raise on click</source>
        <translation>На передний план по щелчку</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="483"/>
        <source>Hardware Acceleration</source>
        <translation>Аппаратное ускорение</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.ui" line="538"/>
        <source>Text quality</source>
        <translation>Качество текста</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Fast</source>
        <translation>Быстрое</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Good</source>
        <translation>Хорошее</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="64"/>
        <source>Best</source>
        <translation>Наилучшее</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Click</source>
        <translation>По щелчку</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Sloppy</source>
        <translation>По положению курсора, исключая рабочий стол</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="66"/>
        <source>Mouse</source>
        <translation>По положению курсора</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Toggle Shade</source>
        <translation>Свернуть в заголовок</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize</source>
        <translation>Распахнуть</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize Horizontally</source>
        <translation>Распахнуть горизонтально</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Maximize Vertically</source>
        <translation>Распахнуть вертикально</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Minimize</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>None</source>
        <translation>Не выбрано</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Lower</source>
        <translation>На задний план</translation>
    </message>
    <message>
        <location filename="../stacer/Pages/GnomeSettings/window_manager_settings.cpp" line="78"/>
        <source>Menu</source>
        <translation>Меню</translation>
    </message>
</context>
</TS>
